@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2007 Imendio AB
+ * Copyright (C) 2008 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -14,8 +15,10 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ *
+ * Authors: Xavier Claessens <xclaesse@gmail.com>
  */
 
 #ifndef __EMPATHY_THEME_IRC_H__
@@ -23,7 +26,7 @@
 
 #include <glib-object.h>
 
-#include "empathy-theme.h"
+#include "empathy-chat-text-view.h"
 
 G_BEGIN_DECLS
 
@@ -38,15 +41,20 @@ typedef struct _EmpathyThemeIrc      EmpathyThemeIrc;
 typedef struct _EmpathyThemeIrcClass EmpathyThemeIrcClass;
 
 struct _EmpathyThemeIrc {
-	EmpathyTheme parent;
+	EmpathyChatTextView parent;
 	gpointer priv;
 };
 
 struct _EmpathyThemeIrcClass {
-	EmpathyThemeClass parent_class;
+	EmpathyChatTextViewClass parent_class;
 };
 
-GType               empathy_theme_irc_get_type                 (void) G_GNUC_CONST;
+#define EMPATHY_THEME_IRC_TAG_NICK_SELF "irc-nick-self"
+#define EMPATHY_THEME_IRC_TAG_NICK_OTHER "irc-nick-other"
+#define EMPATHY_THEME_IRC_TAG_NICK_HIGHLIGHT "irc-nick-highlight"
+
+GType empathy_theme_irc_get_type (void) G_GNUC_CONST;
+EmpathyThemeIrc *empathy_theme_irc_new (void);
 
 G_END_DECLS
 
