@@ -28,9 +28,11 @@
 
 static TpContactFeature contact_features[] = {
 	TP_CONTACT_FEATURE_ALIAS,
+	TP_CONTACT_FEATURE_AVATAR_DATA,
 	TP_CONTACT_FEATURE_PRESENCE,
 	TP_CONTACT_FEATURE_LOCATION,
 	TP_CONTACT_FEATURE_CAPABILITIES,
+	TP_CONTACT_FEATURE_CLIENT_TYPES,
 };
 
 typedef union {
